Unicode Characters
==================

.. py:module:: pyslet.unicode5


Utility Functions
-----------------

..	autofunction::	detect_encoding


Character Classes
-----------------

..	autoclass:: CharClass
	:members:
	:show-inheritance:


Parsing Text and Binary Data
----------------------------

..	autoclass:: BasicParser
	:members:
	:show-inheritance:

..	autoclass:: ParserError
	:members:
	:show-inheritance:
